pub trait ScalarArg<'v>: Sized {
// Required method
fn read(v: &VectorRef<'v>, row: usize) -> UdfResult<Self>;
}Expand description
Read and write views over a single column of a DataChunkHandle, plus the
ScalarArg/ScalarRet marshalling traits.
A Rust type readable from one row of a VectorRef.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".