pub trait ScalarRet {
// Required method
fn write(self, v: &mut VectorMut<'_>, row: usize) -> UdfResult<()>;
}Expand description
Read and write views over a single column of a DataChunkHandle, plus the
ScalarArg/ScalarRet marshalling traits.
A Rust type writable into one row of a VectorMut.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".